@@ -6,6 +6,7 @@
 #include <QQmlContext>
 
 #include <MauiKit3/Core/mauiapp.h>
+#include <MauiKit3/Calendar/moduleinfo.h>
 
 #include <KAboutData>
 #include <KI18n/KLocalizedString>
@@ -16,8 +17,9 @@
 #define ORG_NAME "Maui"
 #define PROJECT_NAME "Agenda"
 #define COMPONENT_NAME "agenda"
-#define PROJECT_DESCRIPTION "View and organize your calendar events."
+#define PROJECT_DESCRIPTION "View and organize your events"
 #define PROJECT_YEAR "2022"
+#define CURRENT_PROJECT_YEAR "2023"
 #define PRODUCT_NAME "maui/agenda"
 #define PROJECT_PAGE "https://mauikit.org"
 #define REPORT_PAGE "https://invent.kde.org/maui/index-fm/-/issues"
@@ -33,8 +35,13 @@ int main(int argc, char *argv[])
 
     KLocalizedString::setApplicationDomain(COMPONENT_NAME);
 
-    KAboutData about(QStringLiteral(COMPONENT_NAME), i18n(PROJECT_NAME), PROJECT_VERSION_STRING, i18n(PROJECT_DESCRIPTION),
-                     KAboutLicense::LGPL_V3, QString("© %1-%2 %3 Development Team").arg(PROJECT_YEAR, QString::number(QDate::currentDate().year()), ORG_NAME), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
+    KAboutData about(QStringLiteral(COMPONENT_NAME),
+                     i18n(PROJECT_NAME),
+                     PROJECT_VERSION_STRING,
+                     i18n(PROJECT_DESCRIPTION),
+                     KAboutLicense::LGPL_V3,
+                     QString("© %1-%2 %3 Development Team").arg(PROJECT_YEAR, CURRENT_PROJECT_YEAR, ORG_NAME),
+                     QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
 
     about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
 
@@ -43,9 +50,15 @@ int main(int argc, char *argv[])
     about.setBugAddress(REPORT_PAGE);
     about.setOrganizationDomain(PROJECT_URI);
     about.setProgramLogo(app.windowIcon());
-    about.addComponent("Akonadi");
+
     about.addCredit(i18n("Kalendar Developers"));
 
+    const auto AkonadiData = MauiKitCalendar::aboutAkonadi();
+    about.addComponent(AkonadiData.name(), "", AkonadiData.version(), AkonadiData.webAddress());
+
+    const auto CalData = MauiKitCalendar::aboutData();
+    about.addComponent(CalData.name(), MauiKitCalendar::buildVersion(), CalData.version(), CalData.webAddress());
+
     KAboutData::setApplicationData(about);
     MauiApp::instance()->setIconName("qrc:/logo.svg");
 
